@@ -87,7 +87,7 @@ first_non_null <- function(...) {
 #' @export
 #' @examples
 #'  data(tips, package = "reshape")
-#'  pMat <- ggpairs(tips, c(1,3,2), color = "sex")
+#'  pMat <- ggpairs(tips, c(1,3,2), mapping = ggplot2::aes_string(color = "sex"))
 #'  pMat # calls print(pMat), which calls print.ggmatrix(pMat)
 #'
 #'  ## defaults; (prints strips on top and right edges of matrix)
@@ -294,6 +294,24 @@ print.ggmatrix <- function(
         next
       }
 
+      if (!is.ggplot(p)) {
+        pushViewport(
+          vplayout(
+            2 * rowPos - 1,
+            ifelse(
+              x$showYAxisPlotLabels,
+              2 * columnPos,
+              (2 * columnPos) - 1
+            )
+          )
+        )
+          suppressMessages(suppressWarnings(
+            print(p)
+          ))
+        popViewport() # 'plot panel' area
+        next
+      }
+
       pGtable <- ggplot_gtable(ggplot_build(p))
 
       ## New axis labels
