@@ -102,7 +102,8 @@ if (getRversion() >= "2.15.1") {
 #'
 #' # utilize ggplot2 aes to switch to thicker lines
 #' gpd <- ggparcoord(data = diamonds.samp, columns = c(1, 5:10), groupColumn = 2,
-#'   title="Parallel Coord. Plot of Diamonds Data", mapping = ggplot2::aes(size = 1))
+#'   title ="Parallel Coord. Plot of Diamonds Data", mapping = ggplot2::aes(size = 1)) +
+#'   ggplot2::scale_size_identity()
 #' # gpd
 #'
 #' # basic parallel coord plot of the msleep data, using 'random' imputation and
@@ -165,6 +166,10 @@ ggparcoord <- function(
   mapping      = NULL,
   title        = ""
 ) {
+
+  if (! identical(class(data), "data.frame")) {
+    data <- as.data.frame(data)
+  }
   saveData <- data
 
   ### Error Checking ###
@@ -487,8 +492,9 @@ ggparcoord <- function(
       mapping = aes(y = NULL, ymin = min, ymax = max, group = variable))
   }
 
-  if (boxplot)
-    p <- p + geom_boxplot(mapping = aes(group = variable), alpha = 0.8)
+  if (boxplot) {
+    p <- p + geom_boxplot(mapping = aes_string(group = "variable"), alpha = 0.8)
+  }
 
   if (!is.null(mapping2$size)) {
     lineSize <- mapping2$size
